.. django-ldap-user-registration documentation master file, created by
   sphinx-quickstart on Thu Jul 26 16:10:02 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-ldap-user-registration's documentation!
=========================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   installation
   configuration



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
